@@ -26,6 +26,7 @@ class SQLAlchemyCRUDRouter(CRUDGenerator[SCHEMA]):
         create_schema: Optional[Type[SCHEMA]] = None,
         update_schema: Optional[Type[SCHEMA]] = None,
         prefix: Optional[str] = None,
+        tags: Optional[List[str]] = None,
         paginate: Optional[int] = None,
         get_all_route: bool = True,
         get_one_route: bool = True,
@@ -33,7 +34,6 @@ class SQLAlchemyCRUDRouter(CRUDGenerator[SCHEMA]):
         update_route: bool = True,
         delete_one_route: bool = True,
         delete_all_route: bool = True,
-        *args: Any,
         **kwargs: Any
     ) -> None:
         assert (
@@ -46,18 +46,18 @@ class SQLAlchemyCRUDRouter(CRUDGenerator[SCHEMA]):
         self._pk_type: type = _utils.get_pk_type(schema, self._pk)
 
         super().__init__(
-            schema,
-            create_schema or _utils.schema_factory(schema, self._pk),
-            update_schema,
-            prefix or db_model.__tablename__,
-            paginate,
-            get_all_route,
-            get_one_route,
-            create_route,
-            update_route,
-            delete_one_route,
-            delete_all_route,
-            *args,
+            schema=schema,
+            create_schema=create_schema,
+            update_schema=update_schema,
+            prefix=prefix or db_model.__tablename__,
+            tags=tags,
+            paginate=paginate,
+            get_all_route=get_all_route,
+            get_one_route=get_one_route,
+            create_route=create_route,
+            update_route=update_route,
+            delete_one_route=delete_one_route,
+            delete_all_route=delete_all_route,
             **kwargs
         )
 
